@@ -496,36 +496,50 @@ Connector.prototype = {
       this.capabilityFlags = [];
   },
 
-  // Get a default value for a capability flag
-  // Asks all steps (in all tasks) until one has a clear opinion
-  // of what the flag should be. If nobody has, returns the
-  // defaultvalue (which can be undefined or null, if you want to
-  // see that no default was found.
-  getCapabilityFlagDefault: function( name, defaultvalue, alias) {
-    for ( var t in this.taskList ) {
-      for ( var s in this.taskList[t].steps ) {
-        var step = this.taskList[t].steps[s];
-        if ((step.getClassName() !== "Comment") && !step.isDisabled ) {
-          var stepdef = step.capabilityFlagDefault(name);
-          if ( stepdef != undefined &&
-                stepdef != null ) {
-            //dump("Flag " + name + " got value " + stepdef + "\n");
-            return stepdef;  // return the first opinion we find
-          }
-          if ( alias ) {
-            var stepdef = step.capabilityFlagDefault(alias);
-            if ( stepdef != undefined &&
-                  stepdef != null ) {
-              //dump("Flag " + name + " got value " + stepdef +
-              //     " via alias " + alias + "\n");
-              return stepdef;
-            }
-          } // alias
-        }
-      } // step loop
+  getCapabilityFlagDefault: function (name, defaultValue, alias) {
+    for (var i=0; i<this.taskList.length; i++) {
+      let block = this.taskList[i].block;
+      let opinion = this.getCapabilityFlagDefaultBlock(block, name, alias);
+      if (opinion != undefined && opinion != null) {
+        return opinion;
+      }
     }
-    //dump("Flag " + name + " defaulting to " + defaultvalue + "\n");
-    return defaultvalue;
+    return defaultValue;
+  },
+
+  // get an opinion for a  default value for a capability flag within a block
+  // or null when no opinion is given
+  getCapabilityFlagDefaultBlock: function (block, name, alias) 
+  {
+    for (let i=0; i<block.steps.length; i++) {
+      let step = block.steps[i];
+      if ((step.getClassName() !== "Comment") && !step.isDisabled ) {
+        let opinion = step.capabilityFlagDefault(name);
+        if (opinion != undefined && opinion != null) {
+          logger.debug("Step "+step+" reported '"+opinion+"' on flag "+name);
+          return opinion;  // return the first opinion we find
+        }
+        if (alias) {
+          let opinion = step.capabilityFlagDefault(alias);
+          logger.debug("Step "+step+" reported '"+opinion+"' on flag "+alias);
+          if (opinion != undefined && opinion != null) {
+            return opinion;
+          }
+        }
+        //handle any blocks
+        let blocks = step.blocks;
+        if (blocks && blocks.length) {
+          for (let j=0; j<blocks.length; j++) {
+            let opinion = this.getCapabilityFlagDefaultBlock(blocks[j], 
+              name, alias);
+            if (opinion != undefined && opinion != null) {
+              return opinion;
+            }
+          }
+        }
+      }
+    }
+    return null;
   },
 
   // Get the value of a capability flag, either from the array of
