@@ -788,7 +788,14 @@ xulHelper = {
   // the highlighting for that too (without recursing, as those
   // tend to be cyclical!)
   highlightNode: function(node, color, userhighlight ) {
-    var nodes = [ node, node.cf_displaynode, node.cf_datanode  ];
+    var nodes = [ node ];
+    try { // Defensive coding, things go wrong if we look at a document that
+          // is gone away (as when moving to a new page, or closing a tab)
+      nodes = [ node, node.cf_displaynode, node.cf_datanode  ];
+    } catch (e) {
+      logger.debug("xulHelper.highlightNode: Caught exception " + e + 
+        " Ignoring it. Probably something funny with the current page");
+    }
     var displaycolor = color;
     //if ( node.getAttribute && node.getAttribute("cf_user_highlight") == color)
     //  userhighlight = true; // use has highlighted this before
