@@ -518,7 +518,7 @@ yf::CF::Session::~Session()
 {
     delete engine;
     if (log_file != -1)
-        close(log_file);
+        ::close(log_file);
     mp::wrbuf cf_log_fname;
     wrbuf_printf(cf_log_fname, "%s.log", wrbuf_cstr(file_area));
     unlink(wrbuf_cstr(cf_log_fname));
@@ -1362,19 +1362,20 @@ Z_APDU *yf::CF::Rep::search_z3950(Z_APDU *req, CF::ZSession *zsession,
     }
     json_remove_node(res);
 
-    int number = 0;
-    mp::util::piggyback(*sr->smallSetUpperBound,
-                        *sr->largeSetLowerBound,
-                        *sr->mediumSetPresentNumber,
-                        zsession->hits,
-                        number);
-
+    Odr_int number = 0;
     std::string addinfo;
     int error_code = 0;
     int number_returned = 0;
     int next_position = 0;
     Z_Records *records = 0;
-    if (number)
+    mp::util::piggyback(*sr->smallSetUpperBound,
+                        *sr->largeSetLowerBound,
+                        *sr->mediumSetPresentNumber,
+                        0,
+                        0,
+                        zsession->hits,
+                        number, 0);
+    if (number > 0)
     {
         Z_ElementSetNames *esn;
         if (number > *sr->smallSetUpperBound)
